@@ -30,7 +30,9 @@ use xor_name::XorName;
 impl Node {
     ///
     pub async fn handle(&mut self, duty: NodeDuty) -> Result<NodeDuties> {
-        info!("Handling NodeDuty: {:?}", duty);
+        if !matches!(duty, NodeDuty::NoOp) {
+            debug!("Handling NodeDuty: {:?}", duty);
+        }
         match duty {
             NodeDuty::Genesis => {
                 self.level_up().await?;
@@ -102,16 +104,15 @@ impl Node {
                 Ok(vec![self.get_section_elders(msg_id, origin).await?])
             }
             NodeDuty::ReceiveRewardProposal(proposal) => {
-                let elder = self.role.as_elder_mut()?;
                 info!("Handling Churn proposal as an Elder");
-                let (churn_process, _, _) = elder.section_funds.as_churning_mut()?;
+                let elder = self.role.as_elder_mut()?;
+                let (churn_process, _) = elder.section_funds.as_churning_mut()?;
                 Ok(vec![churn_process.receive_churn_proposal(proposal).await?])
             }
             NodeDuty::ReceiveRewardAccumulation(accumulation) => {
                 let elder = self.role.as_elder_mut()?;
 
-                let (churn_process, reward_wallets, payments) =
-                    elder.section_funds.as_churning_mut()?;
+                let (churn_process, reward_wallets) = elder.section_funds.as_churning_mut()?;
 
                 let mut ops = vec![
                     churn_process
@@ -123,10 +124,7 @@ impl Node {
                     let reward_sum = credit_proofs.sum();
                     ops.extend(Self::propagate_credits(credit_proofs)?);
                     // update state
-                    elder.section_funds = SectionFunds::KeepingNodeWallets {
-                        wallets: reward_wallets.clone(),
-                        payments: payments.clone(),
-                    };
+                    elder.section_funds = SectionFunds::KeepingNodeWallets(reward_wallets.clone());
                     let section_key = &self.network_api.section_public_key().await?;
                     info!(
                         "COMPLETED SPLIT. New section: ({}). Total rewards paid: {}.",
@@ -174,15 +172,9 @@ impl Node {
             }
             NodeDuty::ProcessLostMember { name, .. } => {
                 info!("Member Lost: {:?}", name);
-                let mut ops = vec![];
-
-                info!("Setting JoinsAllowed to `True` for replacing the member left");
-                ops.push(NodeDuty::SetNodeJoinsAllowed(true));
-
                 let elder = self.role.as_elder_mut()?;
                 elder.section_funds.remove_node_wallet(name);
-
-                Ok(ops)
+                Ok(vec![NodeDuty::SetNodeJoinsAllowed(true)])
             }
             //
             // ---------- Levelling --------------
@@ -266,23 +258,10 @@ impl Node {
             //
             // -------- Immutable chunks --------
             NodeDuty::ReadChunk { read, msg_id, .. } => {
-                // TODO: remove this conditional branching
-                // routing should take care of this
-                let data_section_addr = read.dst_address();
-                if self
-                    .network_api
-                    .our_prefix()
-                    .await
-                    .matches(&&data_section_addr)
-                {
-                    let adult = self.role.as_adult_mut()?;
-                    let mut ops = adult.chunks.read(&read, msg_id);
-                    ops.extend(adult.chunks.check_storage().await?);
-                    Ok(ops)
-                } else {
-                    log::error!("MessageId: {:?} NodeCmd::Chunks {:?} should not have reached a wrong Adult", msg_id, read);
-                    Ok(vec![])
-                }
+                let adult = self.role.as_adult_mut()?;
+                let mut ops = adult.chunks.read(&read, msg_id);
+                ops.extend(adult.chunks.check_storage().await?);
+                Ok(ops)
             }
             NodeDuty::WriteChunk {
                 write,
@@ -292,8 +271,8 @@ impl Node {
                 let adult = self.role.as_adult_mut()?;
                 Ok(vec![adult.chunks.write(&write, msg_id, origin).await?])
             }
-            NodeDuty::ProcessRepublish { chunk, msg_id } => {
-                log::info!("Processing republish with MessageId: {:?}", msg_id);
+            NodeDuty::ProcessRepublish { chunk, msg_id, .. } => {
+                info!("Processing republish with MessageId: {:?}", msg_id);
                 let elder = self.role.as_elder_mut()?;
                 Ok(vec![elder.meta_data.republish_chunk(chunk).await?])
             }
@@ -343,7 +322,6 @@ impl Node {
                             id,
                         },
                         dst: DstLocation::Section(data_section_addr),
-                        // TBD
                         section_source: false,
                         aggregation: Aggregation::None,
                     })])
@@ -380,12 +358,7 @@ impl Node {
             }
             NodeDuty::ProcessDataPayment { msg, origin } => {
                 let elder = self.role.as_elder_mut()?;
-                elder.transfers.process_payment(&msg, origin).await
-            }
-            NodeDuty::AddPayment(credit) => {
-                let elder = self.role.as_elder_mut()?;
-                elder.section_funds.add_payment(credit);
-                Ok(vec![])
+                Ok(vec![elder.transfers.process_payment(&msg, origin).await?])
             }
             NodeDuty::ReplicateChunk { data, id } => {
                 let adult = self.role.as_adult_mut()?;
