@@ -42,7 +42,6 @@ pub type NodeDuties = Vec<NodeDuty>;
 /// Common duties run by all nodes.
 #[allow(clippy::large_enum_variant)]
 pub enum NodeDuty {
-    AddPayment(CreditAgreementProof),
     GetNodeWalletKey {
         node_name: XorName,
         msg_id: MessageId,
@@ -233,7 +232,6 @@ impl Debug for NodeDuty {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Genesis { .. } => write!(f, "Genesis"),
-            Self::AddPayment { .. } => write!(f, "AddPayment"),
             Self::GetNodeWalletKey { .. } => write!(f, "GetNodeWalletKey"),
             Self::PropagateTransfer { .. } => write!(f, "PropagateTransfer"),
             Self::SetNodeWallet { .. } => write!(f, "SetNodeWallet"),
