@@ -111,6 +111,10 @@ impl Transfers {
         self.replicas.keep_keys_of(prefix).await
     }
 
+    pub async fn payments(&self) -> Result<Token> {
+        self.replicas.balance(self.section_wallet_id()).await
+    }
+
     /// Get latest StoreCost for the given number of bytes.
     /// Also check for Section storage capacity and report accordingly.
     pub async fn get_store_cost(
@@ -150,7 +154,7 @@ impl Transfers {
     /// Makes sure the payment contained
     /// within a data write, is credited
     /// to the section funds.
-    pub async fn process_payment(&self, msg: &Message, origin: EndUser) -> Result<NodeDuties> {
+    pub async fn process_payment(&self, msg: &Message, origin: EndUser) -> Result<NodeDuty> {
         debug!(">>>> processing payment");
         let (payment, data_cmd, num_bytes, dst_address) = match &msg {
             Message::Cmd {
@@ -162,7 +166,7 @@ impl Transfers {
                 utils::serialise(cmd)?.len() as u64,
                 cmd.dst_address(),
             ),
-            _ => return Ok(vec![]),
+            _ => return Ok(NodeDuty::NoOp),
         };
 
         // Make sure we are actually at the correct replicas,
@@ -175,7 +179,7 @@ impl Transfers {
         if recipient_is_not_section {
             warn!("Payment: recipient is not section");
             let origin = SrcLocation::EndUser(EndUser::AllClients(payment.sender()));
-            return Ok(vec![NodeDuty::Send(OutgoingMsg {
+            return Ok(NodeDuty::Send(OutgoingMsg {
                 msg: Message::CmdError {
                     error: CmdError::Transfer(TransferRegistration(ErrorMessage::NoSuchRecipient)),
                     id: MessageId::in_response_to(&msg.id()),
@@ -184,7 +188,7 @@ impl Transfers {
                 section_source: false, // strictly this is not correct, but we don't expect responses to a response..
                 dst: origin.to_dst(),
                 aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-            })]);
+            }));
         }
         let registration = self.replicas.register(&payment).await;
         let result = match registration {
@@ -199,14 +203,13 @@ impl Transfers {
             Err(error) => Err(error), // not using TransferPropagation error, since that is for NodeCmds, so wouldn't be returned to client.
         };
         match result {
-            Ok(e) => {
+            Ok(_) => {
                 let total_cost = self.rate_limit.from(num_bytes).await;
                 info!("Payment: registration and propagation succeeded. (Store cost: {}, paid amount: {}.)", total_cost, payment.amount());
                 info!(
                     "Section balance: {}",
                     self.replicas.balance(payment.recipient()).await?
                 );
-                let mut ops = vec![NodeDuty::AddPayment(e.credit_proof)];
                 if total_cost > payment.amount() {
                     // Paying too little will see the amount be forfeited.
                     // This prevents spam of the network.
@@ -217,7 +220,7 @@ impl Transfers {
                     );
                     // todo, better error, like `TooLowPayment`
                     let origin = SrcLocation::EndUser(EndUser::AllClients(payment.sender()));
-                    ops.push(NodeDuty::Send(OutgoingMsg {
+                    return Ok(NodeDuty::Send(OutgoingMsg {
                         msg: Message::CmdError {
                             error: CmdError::Transfer(TransferRegistration(
                                 ErrorMessage::InsufficientBalance,
@@ -229,12 +232,9 @@ impl Transfers {
                         dst: origin.to_dst(),
                         aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
                     }));
-                    return Ok(ops);
                 }
                 info!("Payment: forwarding data..");
-                // consider having the section actor be
-                // informed of this transfer as well..
-                ops.push(NodeDuty::Send(OutgoingMsg {
+                Ok(NodeDuty::Send(OutgoingMsg {
                     msg: Message::NodeCmd {
                         cmd: NodeCmd::Metadata {
                             cmd: data_cmd.clone(),
@@ -245,13 +245,12 @@ impl Transfers {
                     section_source: true, // i.e. errors go to our section
                     dst: DstLocation::Section(dst_address),
                     aggregation: Aggregation::AtDestination,
-                }));
-                Ok(ops)
+                }))
             }
             Err(e) => {
                 warn!("Payment: registration or propagation failed: {:?}", e);
                 let origin = SrcLocation::EndUser(EndUser::AllClients(payment.sender()));
-                Ok(vec![NodeDuty::Send(OutgoingMsg {
+                Ok(NodeDuty::Send(OutgoingMsg {
                     msg: Message::CmdError {
                         error: CmdError::Transfer(TransferRegistration(
                             ErrorMessage::PaymentFailed,
@@ -262,7 +261,7 @@ impl Transfers {
                     section_source: false, // strictly this is not correct, but we don't expect responses to an error..
                     dst: origin.to_dst(),
                     aggregation: Aggregation::None, // TODO: to_be_aggregated: Aggregation::AtDestination,
-                })])
+                }))
             }
         }
     }
